==> nextcloud-26.0.11p1.tgz: nextcloud/apps/circles/l10n/ka.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Circles",
    "Circles' files" : "Circles' files",
    "Select circles to filter by" : "Select circles to filter by",
    "No circles found" : "No circles found",
    "Please select circles to filter by" : "Please select circles to filter by",
    "No files found for the selected circles" : "No files found for the selected circles",
    "You created the circle {circle}" : "You created the circle {circle}",
    "{author} created the circle {circle}" : "{author} created the circle {circle}",
    "You deleted {circle}" : "You deleted {circle}",
    "{author} deleted {circle}" : "{author} deleted {circle}",
    "You linked {group} to {circle}" : "You linked {group} to {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} has been linked to {circle} by {author}",
    "You unlinked {group} from {circle}" : "You unlinked {group} from {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} has been unlinked from {circle} by {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "You changed the level of the linked group {group} in {circle} to %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} changed the level of the linked group {group} in {circle} to %1$s",
    "You sent a request to link {circle} with {remote}" : "You sent a request to link {circle} with {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sent a request to link {circle} with {remote}",
    "{remote} requested a link with {circle}" : "{remote} requested a link with {circle}",
    "The request to link {circle} with {remote} has been rejected" : "The request to link {circle} with {remote} has been rejected",
    "The request to link {remote} with {circle} has been canceled remotely" : "The request to link {remote} with {circle} has been canceled remotely",
    "The request to link {circle} with {remote} has been accepted" : "The request to link {circle} with {remote} has been accepted",
    "You dismissed the request to link {remote} with {circle}" : "You dismissed the request to link {remote} with {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} dismissed the request to link {remote} with {circle}",
    "You canceled the request to link {circle} with {remote}" : "You canceled the request to link {circle} with {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} canceled the request to link {circle} with {remote}",
    "You accepted the request to link {remote} with {circle}" : "You accepted the request to link {remote} with {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} accepted the request to link {remote} with {circle}",
    "A link between {circle} and {remote} is now up and running" : "A link between {circle} and {remote} is now up and running",
    "The link between {circle} and {remote} has been shutdown remotely" : "The link between {circle} and {remote} has been shutdown remotely",
    "You closed the link between {circle} and {remote}" : "You closed the link between {circle} and {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} closed the link between {circle} and {remote}",
    "You joined {circle}" : "You joined {circle}",
    "{member} joined {circle}" : "{member} joined {circle}",
    "You accepted the invitation to join {circle}" : "You accepted the invitation to join {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepted the invitation to join {circle}",
    "You added {member} as member to {circle}" : "You added {member} as member to {circle}",
    "You have been added as member to {circle} by {author}" : "You have been added as member to {circle} by {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} has been added as member to {circle} by {author}",
    "You added {external} to {circle}" : "You added {external} to {circle}",
    "{external} has been added to {circle} by {author}" : "{external} has been added to {circle} by {author}",
    "You accepted {member}'s request to join {circle}" : "You accepted {member}'s request to join {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Your request to join {circle} has been accepted by {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s request to join {circle} has been accepted by {author}",
    "You left {circle}" : "You left {circle}",
    "{member} left {circle}" : "{member} left {circle}",
    "You declined the invitation to join {circle}" : "You declined the invitation to join {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declined an invitation to join {circle}",
    "You cancelled your request to join {circle}" : "You cancelled your request to join {circle}",
    "{member} cancelled his request to join {circle}" : "{member} cancelled his request to join {circle}",
    "You removed {member} from {circle}" : "You removed {member} from {circle}",
    "You have been removed from {circle} by {author}" : "You have been removed from {circle} by {author}",
    "{member} has been removed from {circle} by {author}" : "{member} has been removed from {circle} by {author}",
    "You removed {external} from {circle}" : "You removed {external} from {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} has been removed from {circle} by {author}",
    "You cancelled {member}'s invitation to join {circle}" : "You cancelled {member}'s invitation to join {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Your invitation to join {circle} has been cancelled by {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelled {member}'s invitation to join {circle}",
    "You dismissed {member}'s request to join {circle}" : "You dismissed {member}'s request to join {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Your request to join {circle} has been dismissed by {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s request to join {circle} has been dismissed by {author}",
    "You invited {member} to join {circle}" : "You invited {member} to join {circle}",
    "You have been invited to join {circle} by {author}" : "You have been invited to join {circle} by {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} has been invited to join {circle} by {author}",
    "You changed {member}'s level in {circle} to %1$s" : "You changed {member}'s level in {circle} to %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} changed your level in {circle} to %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} changed {member}'s level in {circle} to %1$s",
    "You sent a request to join {circle}" : "You sent a request to join {circle}",
    "{member} sent a request to join {circle}" : "{member} sent a request to join {circle}",
    "You are the new owner of {circle}" : "You are the new owner of {circle}",
    "{member} is the new owner of {circle}" : "{member} is the new owner of {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "On events happening in a <strong>Circle</strong> of which you are a member",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Any important event in a <strong>Circle</strong> you are moderating",
    "On global events happening in any <strong>Circle</strong>" : "On global events happening in any <strong>Circle</strong>",
    "Shared to Circles" : "Shared to Circles",
    "Single" : "Single",
    "Personal" : "Personal",
    "System" : "System",
    "Visible" : "Visible",
    "Open" : "Open",
    "Invite" : "Invite",
    "Join Request" : "Join Request",
    "Friends" : "Friends",
    "Password Protected" : "Password Protected",
    "No Owner" : "No Owner",
    "Hidden" : "Hidden",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Root",
    "Circle Invite" : "Circle Invite",
    "Federated" : "Federated",
    "Mount point" : "Mount point",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Group",
    "Email Address" : "Email Address",
    "Contact" : "Contact",
    "Circle" : "Circle",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "Member",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s shared »%s« with you.",
    "%s shared »%s« with \"%s\"." : "%s shared »%s« with \"%s\".",
    "%s on %s" : "%s on %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it.",
    "Password to access »%1$s« shared to you by %2$s" : "Password to access »%1$s« shared to you by %2$s",
    "Password to access »%s«" : "Password to access »%s«",
    "It is protected with the following password:" : "It is protected with the following password:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Click the button below to open it.",
    "Open »%s«" : "Open »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
    "Password to access files shared to you by %1$s" : "Password to access files shared to you by %1$s",
    "Password to access files" : "Password to access files",
    "%s shared multiple files with \"%s\"." : "%s shared multiple files with \"%s\".",
    "%s shared multiple files with you." : "%s shared multiple files with you.",
    "Boot up" : "Boot up",
    "Nextcloud Initialization" : "Nextcloud Initialization",
    "Circles App Initialization" : "Circles App Initialization",
    "Fresh installation status" : "Fresh installation status",
    "Building Local Database" : "Building Local Database",
    "Testing Basic Circle Creation" : "Testing Basic Circle Creation",
    "Adding local users and moderators" : "Adding local users and moderators",
    "Circle not found" : "Circle not found",
    "Circle not found " : "Circle not found ",
    "This member does not exist" : "This member does not exist",
    "This account is already a member of the circle" : "This account is already a member of the circle",
    "Federated link not found" : "Federated link not found",
    "This feature is not available for personal circles" : "This feature is not available for personal circles",
    "The circle is not federated" : "The circle is not federated",
    "You cannot join this circle" : "You cannot join this circle",
    "This member is not a moderator" : "This member is not a moderator",
    "Insufficient privileges" : "Insufficient privileges",
    "This member is the owner of the circle" : "This member is the owner of the circle",
    "Level cannot be changed for this type of member" : "Level cannot be changed for this type of member",
    "You are already a member of this circle" : "You are already a member of this circle",
    "You have been blocked from this circle" : "You have been blocked from this circle",
    "The account is already a member of this circle" : "The account is already a member of this circle",
    "The account has already been invited into this circle" : "The account has already been invited into this circle",
    "%s (Circle owned by %s)" : "%s (Circle owned by %s)",
    "You are now a member of the Circle \"%2$s\"" : "You are now a member of the Circle \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "You have been invited by %1$s into the Circle \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sent a request to be a member of the Circle \"%2$s\"",
    "Accept" : "Accept",
    "Refuse" : "Refuse",
    "Leave the circle" : "Leave the circle",
    "%s" : "%s",
    "Personal Circle" : "Personal Circle",
    "%s owned by %s" : "%s owned by %s",
    "You need a specify a type of circle" : "You need a specify a type of circle",
    "A circle with that name exists" : "A circle with that name exists",
    "This member is not the owner of the circle" : "This member is not the owner of the circle",
    "This member is not an admin of the circle" : "This member is not an admin of the circle",
    "Group contains too many members" : "Group contains too many members",
    "This group does not exist" : "This group does not exist",
    "This group is already linked to the circle" : "This group is already linked to the circle",
    "You cannot edit level in a personal circle" : "You cannot edit level in a personal circle",
    "Group cannot be set as owner of a circle" : "Group cannot be set as owner of a circle",
    "now" : "now",
    "This account does not exist" : "This account does not exist",
    "Email format is not valid" : "Email format is not valid",
    "This contact is not available" : "This contact is not available",
    "You have no permission to create a new circle" : "You have no permission to create a new circle",
    "%s shared a file with \"%s\"." : "%s shared a file with \"%s\".",
    "%s shared a file with you." : "%s shared a file with you.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s shared some content with you. You should have already received a separate email with a link to access it.",
    "Password to access content shared with you by %1$s" : "Password to access content shared with you by %1$s",
    "Password to access content" : "Password to access content",
    "This item is already shared with this circle" : "This item is already shared with this circle",
    "Bring cloud-users closer together." : "Bring cloud-users closer together.",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose.",
    "No files in here" : "No files in here",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "Initialisation Nextcloud" : "Initialisation Nextcloud",
    "Initialisation Circles App" : "Initialisation Circles App"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/circles/l10n/ka.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "You deleted {circle}",
    "{author} deleted {circle}" : "{author} deleted {circle}",
    "You joined {circle}" : "You joined {circle}",
    "{member} joined {circle}" : "{member} joined {circle}",
    "You accepted the invitation to join {circle}" : "You accepted the invitation to join {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} accepted the invitation to join {circle}",
    "You added {member} as member to {circle}" : "You added {member} as member to {circle}",
    "You have been added as member to {circle} by {author}" : "You have been added as member to {circle} by {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} has been added as member to {circle} by {author}",
    "You added {external} to {circle}" : "You added {external} to {circle}",
    "{external} has been added to {circle} by {author}" : "{external} has been added to {circle} by {author}",
    "You accepted {member}'s request to join {circle}" : "You accepted {member}'s request to join {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Your request to join {circle} has been accepted by {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s request to join {circle} has been accepted by {author}",
    "You left {circle}" : "You left {circle}",
    "{member} left {circle}" : "{member} left {circle}",
    "You declined the invitation to join {circle}" : "You declined the invitation to join {circle}",
    "{member} declined an invitation to join {circle}" : "{member} declined an invitation to join {circle}",
    "You cancelled your request to join {circle}" : "You cancelled your request to join {circle}",
    "You removed {member} from {circle}" : "You removed {member} from {circle}",
    "You have been removed from {circle} by {author}" : "You have been removed from {circle} by {author}",
    "{member} has been removed from {circle} by {author}" : "{member} has been removed from {circle} by {author}",
    "You removed {external} from {circle}" : "You removed {external} from {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} has been removed from {circle} by {author}",
    "You cancelled {member}'s invitation to join {circle}" : "You cancelled {member}'s invitation to join {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Your invitation to join {circle} has been cancelled by {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelled {member}'s invitation to join {circle}",
    "You dismissed {member}'s request to join {circle}" : "You dismissed {member}'s request to join {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Your request to join {circle} has been dismissed by {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s request to join {circle} has been dismissed by {author}",
    "You invited {member} to join {circle}" : "You invited {member} to join {circle}",
    "You have been invited to join {circle} by {author}" : "You have been invited to join {circle} by {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} has been invited to join {circle} by {author}",
    "You changed {member}'s level in {circle} to %1$s" : "You changed {member}'s level in {circle} to %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} changed your level in {circle} to %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} changed {member}'s level in {circle} to %1$s",
    "You sent a request to join {circle}" : "You sent a request to join {circle}",
    "{member} sent a request to join {circle}" : "{member} sent a request to join {circle}",
    "You are the new owner of {circle}" : "You are the new owner of {circle}",
    "{member} is the new owner of {circle}" : "{member} is the new owner of {circle}",
    "Shared to Circles" : "Shared to Circles",
    "Single" : "Single",
    "Personal" : "Personal",
    "System" : "System",
    "Visible" : "Visible",
    "Open" : "Open",
    "Invite" : "Invite",
    "Friends" : "Friends",
    "No Owner" : "No Owner",
    "Hidden" : "Hidden",
    "Backend" : "Backend",
    "Local" : "Local",
    "Root" : "Root",
    "Federated" : "Federated",
    "Mount point" : "Mount point",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Group",
    "Email address" : "Email address",
    "Contact" : "Contact",
    "Circle" : "Circle",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "Member",
    "Moderator" : "Moderator",
    "Admin" : "Admin",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "%s shared »%s« with you.",
    "%s shared »%s« with \"%s\"." : "%s shared »%s« with \"%s\".",
    "%s on %s" : "%s on %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it.",
    "Password to access »%1$s« shared to you by %2$s" : "Password to access »%1$s« shared to you by %2$s",
    "Password to access »%s«" : "Password to access »%s«",
    "It is protected with the following password:" : "It is protected with the following password:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Click the button below to open it.",
    "Open »%s«" : "Open »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
    "Password to access files shared to you by %1$s" : "Password to access files shared to you by %1$s",
    "Password to access files" : "Password to access files",
    "%s shared multiple files with \"%s\"." : "%s shared multiple files with \"%s\".",
    "%s shared multiple files with you." : "%s shared multiple files with you.",
    "Boot up" : "Boot up",
    "Nextcloud Initialization" : "Nextcloud Initialization",
    "Circles App Initialization" : "Circles App Initialization",
    "Fresh installation status" : "Fresh installation status",
    "Building Local Database" : "Building Local Database",
    "Testing Basic Circle Creation" : "Testing Basic Circle Creation",
    "Adding local users and moderators" : "Adding local users and moderators",
    "This feature is not available for personal circles" : "This feature is not available for personal circles",
    "This member is not a moderator" : "This member is not a moderator",
    "Insufficient privileges" : "Insufficient privileges",
    "This member does not exist" : "This member does not exist",
    "Level cannot be changed for this type of member" : "Level cannot be changed for this type of member",
    "You are already a member of this circle" : "You are already a member of this circle",
    "You have been blocked from this circle" : "You have been blocked from this circle",
    "The account is already a member of this circle" : "The account is already a member of this circle",
    "The account has already been invited into this circle" : "The account has already been invited into this circle",
    "You are now a member of the Circle \"%2$s\"" : "You are now a member of the Circle \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "You have been invited by %1$s into the Circle \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sent a request to be a member of the Circle \"%2$s\"",
    "Accept" : "Accept",
    "Refuse" : "Refuse",
    "Leave the circle" : "Leave the circle",
    "%s" : "%s",
    "%s owned by %s" : "%s owned by %s",
    "%s shared a file with \"%s\"." : "%s shared a file with \"%s\".",
    "%s shared a file with you." : "%s shared a file with you.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s shared some content with you. You should have already received a separate email with a link to access it.",
    "Password to access content shared with you by %1$s" : "Password to access content shared with you by %1$s",
    "Password to access content" : "Password to access content",
    "Bring cloud-users closer together." : "Bring cloud-users closer together.",
    "No files in here" : "No files in here",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "Circles" : "Circles",
    "Circles' files" : "Circles' files",
    "Select circles to filter by" : "Select circles to filter by",
    "No circles found" : "No circles found",
    "Please select circles to filter by" : "Please select circles to filter by",
    "No files found for the selected circles" : "No files found for the selected circles",
    "You created the circle {circle}" : "You created the circle {circle}",
    "{author} created the circle {circle}" : "{author} created the circle {circle}",
    "You linked {group} to {circle}" : "You linked {group} to {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} has been linked to {circle} by {author}",
    "You unlinked {group} from {circle}" : "You unlinked {group} from {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} has been unlinked from {circle} by {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "You changed the level of the linked group {group} in {circle} to %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} changed the level of the linked group {group} in {circle} to %1$s",
    "You sent a request to link {circle} with {remote}" : "You sent a request to link {circle} with {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sent a request to link {circle} with {remote}",
    "{remote} requested a link with {circle}" : "{remote} requested a link with {circle}",
    "The request to link {circle} with {remote} has been rejected" : "The request to link {circle} with {remote} has been rejected",
    "The request to link {remote} with {circle} has been canceled remotely" : "The request to link {remote} with {circle} has been canceled remotely",
    "The request to link {circle} with {remote} has been accepted" : "The request to link {circle} with {remote} has been accepted",
    "You dismissed the request to link {remote} with {circle}" : "You dismissed the request to link {remote} with {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} dismissed the request to link {remote} with {circle}",
    "You canceled the request to link {circle} with {remote}" : "You canceled the request to link {circle} with {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} canceled the request to link {circle} with {remote}",
    "You accepted the request to link {remote} with {circle}" : "You accepted the request to link {remote} with {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} accepted the request to link {remote} with {circle}",
    "A link between {circle} and {remote} is now up and running" : "A link between {circle} and {remote} is now up and running",
    "The link between {circle} and {remote} has been shutdown remotely" : "The link between {circle} and {remote} has been shutdown remotely",
    "You closed the link between {circle} and {remote}" : "You closed the link between {circle} and {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} closed the link between {circle} and {remote}",
    "{member} cancelled his request to join {circle}" : "{member} cancelled his request to join {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "On events happening in a <strong>Circle</strong> of which you are a member",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Any important event in a <strong>Circle</strong> you are moderating",
    "On global events happening in any <strong>Circle</strong>" : "On global events happening in any <strong>Circle</strong>",
    "Join Request" : "Join Request",
    "Password Protected" : "Password Protected",
    "Circle Invite" : "Circle Invite",
    "Email Address" : "Email Address",
    "Initialisation Nextcloud" : "Initialisation Nextcloud",
    "Initialisation Circles App" : "Initialisation Circles App",
    "Circle not found" : "Circle not found",
    "Circle not found " : "Circle not found ",
    "This account is already a member of the circle" : "This account is already a member of the circle",
    "Federated link not found" : "Federated link not found",
    "The circle is not federated" : "The circle is not federated",
    "You cannot join this circle" : "You cannot join this circle",
    "This member is the owner of the circle" : "This member is the owner of the circle",
    "%s (Circle owned by %s)" : "%s (Circle owned by %s)",
    "Personal Circle" : "Personal Circle",
    "You need a specify a type of circle" : "You need a specify a type of circle",
    "A circle with that name exists" : "A circle with that name exists",
    "This member is not the owner of the circle" : "This member is not the owner of the circle",
    "This member is not an admin of the circle" : "This member is not an admin of the circle",
    "Group contains too many members" : "Group contains too many members",
    "This group does not exist" : "This group does not exist",
    "This group is already linked to the circle" : "This group is already linked to the circle",
    "You cannot edit level in a personal circle" : "You cannot edit level in a personal circle",
    "Group cannot be set as owner of a circle" : "Group cannot be set as owner of a circle",
    "now" : "now",
    "This account does not exist" : "This account does not exist",
    "Email format is not valid" : "Email format is not valid",
    "This contact is not available" : "This contact is not available",
    "You have no permission to create a new circle" : "You have no permission to create a new circle",
    "This item is already shared with this circle" : "This item is already shared with this circle",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose."
},
"nplurals=2; plural=(n!=1);");
